"""The Exome Python client library."""
# Copyright 2023 WHERE TRUE Technologies.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import logging
import warnings
from contextlib import contextmanager

import adbc_driver_flightsql.dbapi as flight_sql
import grpc
from adbc_driver_flightsql import DatabaseOptions

from exon_py.proto.exome.v1 import catalog_pb2, catalog_pb2_grpc, health_check_pb2, health_check_pb2_grpc

warnings.simplefilter(action="ignore", category=Warning)

logger = logging.getLogger(__name__)

__all__ = [
    "connect",
    "ExomeConnection",
]


class ExomeError(Exception):
    """An error raised by Exome."""

    def __init__(self, *args: object) -> None:
        """Initialize the error."""
        super().__init__(*args)

    @classmethod
    def from_grpc_error(cls, grpc_error: grpc.RpcError):
        """Create an ExomeError from a gRPC error."""
        return cls(grpc_error.details())


class ExomeGrpcConnection:
    """A connection to an Exome server."""

    def __init__(
        self,
        stub: catalog_pb2_grpc.CatalogServiceStub,
        token: str,
    ):
        """Create a new connection to an Exome server."""
        self.stub = stub
        self.token = token


class ExomeConnection:
    """A connection to an Exome server."""

    def __init__(
        self,
        flight_conn: flight_sql.Connection,
        exome_grpc_connection: ExomeGrpcConnection,
    ):
        """Create a new connection to an Exome server."""
        self.flight_conn = flight_conn
        self.exome_grpc_connection = exome_grpc_connection

    def set_library_id(self, library_id: str):
        """Set the library ID."""
        # Make api call to associated the library_id with the connection

    @contextmanager
    def cursor(self):
        """Return a cursor for the connection."""
        cursor = self.flight_conn.cursor()

        try:
            yield cursor

        # pylint: disable=invalid-name
        except ExomeError as e:
            raise e

        finally:
            cursor.close()

    def close(self):
        """Close the connection."""
        self.flight_conn.close()

    def __repr__(self):
        """Return a string representation of the connection."""
        return "ExomeConnection()"


def _flight_sql_connect(uri: str, token: str, protocol: str = "grpc+tls", *, skip_verify: bool = True):
    """Connect to an Exome server."""
    try:
        flight_connection = flight_sql.connect(
            uri=f"{protocol}://{uri}",
            db_kwargs={
                DatabaseOptions.TLS_SKIP_VERIFY.value: str(skip_verify).lower(),
                DatabaseOptions.AUTHORIZATION_HEADER.value: token,
            },
        )

    # pylint: disable=invalid-name
    except Exception as e:
        error_msg = f"Error connecting to Exome server: {e}"
        raise ExomeError(error_msg) from None

    return flight_connection


def _connect_to_exome_request(
    stub: catalog_pb2_grpc.CatalogServiceStub,
    get_token_request: catalog_pb2.GetTokenRequest,
) -> str:
    """Make the actual request to get the token."""
    try:
        token_response = stub.GetToken(get_token_request)

    # pylint: disable=invalid-name
    except grpc.RpcError as e:
        logger.error("Error connecting to Exome server: %s", e)
        raise ExomeError.from_grpc_error(e)

    # pylint: disable=invalid-name
    except Exception as e:
        raise ExomeError(str(e)) from None

    token = token_response.token

    return token


def connect_to_exome(uri: str, username: str, password: str) -> ExomeGrpcConnection:
    creds = grpc.ssl_channel_credentials(root_certificates=None, private_key=None, certificate_chain=None)

    channel = grpc.secure_channel(uri, creds)
    stub = catalog_pb2_grpc.CatalogServiceStub(channel)

    token_request = catalog_pb2.GetTokenRequest(email=username, password=password)

    token = _connect_to_exome_request(stub, token_request)
    exome_grpc_connection = ExomeGrpcConnection(stub, token)

    logger.info("Connected to Exome server at %s", uri)

    return exome_grpc_connection


@contextmanager
def connect(
    username: str,
    password: str,
    organization_name: str = "Public",  # TODO: unused for now
    *,
    uri: str = "adbc.exome.wheretrue.com:443",
    skip_verify: bool = False,
):
    """Connect to an Exome server."""
    exome_connection = connect_to_exome(uri, username, password)

    flight_connection = _flight_sql_connect(uri, exome_connection.token, skip_verify=skip_verify)

    exome_conn = ExomeConnection(flight_connection, exome_connection)

    try:
        yield exome_conn

    # pylint: disable=invalid-name
    except ExomeError as e:
        raise e

    finally:
        exome_conn.close()


def health_check(uri: str) -> health_check_pb2.HealthCheckResponse:
    """Return the health of the Exome server.

    Args:
        uri (str): The URI of the Exome server. For example `adbc.exome.wheretrue.com`.

    Returns:
        health_check_pb2.HealthCheckResponse: The health of the Exome server.
    """
    creds = grpc.ssl_channel_credentials(root_certificates=None, private_key=None, certificate_chain=None)

    channel = grpc.secure_channel(uri, creds)

    stub = health_check_pb2_grpc.HealthStub(channel)

    return stub.Check(health_check_pb2.HealthCheckRequest(service="exome"))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exome/v1/catalog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x65xome/v1/catalog.proto\x12\x08\x65xome.v1\"2\n\x0fGetTokenRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"!\n\x10GetTokenResponse\x12\r\n\x05token\x18\x01 \x01(\t\"M\n\x0fRunQueryRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x12\n\nlibrary_id\x18\x02 \x01(\t\x12\x17\n\x0forganization_id\x18\x03 \x01(\t\"\'\n\x10RunQueryResponse\x12\x13\n\x0bipcResponse\x18\x01 \x01(\x0c\"P\n\x0cOrganization\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x03 \x01(\t\x12\x12\n\nupdated_at\x18\x04 \x01(\t\"1\n\x16GetOrganizationRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\"G\n\x17GetOrganizationResponse\x12,\n\x0corganization\x18\x01 \x01(\x0b\x32\x16.exome.v1.Organization\",\n\x1bGetUserOrganizationsRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"M\n\x1cGetUserOrganizationsResponse\x12-\n\rorganizations\x18\x01 \x03(\x0b\x32\x16.exome.v1.Organization\"d\n\x04User\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x11\n\tlast_name\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\t\x12\x12\n\nupdated_at\x18\x05 \x01(\t\"I\n\x11\x43reateUserRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x11\n\tlast_name\x18\x03 \x01(\t\"#\n\x12\x43reateUserResponse\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"Z\n\x1d\x43reateUserAuthProviderRequest\x12\x14\n\x0c\x61uth_service\x18\x01 \x01(\t\x12\x0f\n\x07\x61uth_id\x18\x02 \x01(\t\x12\x12\n\nuser_email\x18\x03 \x01(\t\" \n\x1e\x43reateUserAuthProviderResponse\"\x1f\n\x0eGetUserRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"/\n\x0fGetUserResponse\x12\x1c\n\x04user\x18\x01 \x01(\x0b\x32\x0e.exome.v1.User\"&\n\x15GetUserByEmailRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"6\n\x16GetUserByEmailResponse\x12\x1c\n\x04user\x18\x01 \x01(\x0b\x32\x0e.exome.v1.User\"\x18\n\x16ListFileFormatsRequest\"E\n\x17ListFileFormatsResponse\x12*\n\x0c\x66ile_formats\x18\x01 \x03(\x0b\x32\x14.exome.v1.FileFormat\"B\n\nFileFormat\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncreated_at\x18\x02 \x01(\t\x12\x12\n\nupdated_at\x18\x03 \x01(\t\"`\n\x07Library\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\t\x12\x12\n\nupdated_at\x18\x05 \x01(\t\"R\n\x14\x43reateLibraryRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x17\n\x0forganization_id\x18\x03 \x01(\t\"#\n\x15\x43reateLibraryResponse\x12\n\n\x02id\x18\x01 \x01(\t\"/\n\x14ListLibrariesRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\"=\n\x15ListLibrariesResponse\x12$\n\tlibraries\x18\x01 \x03(\x0b\x32\x11.exome.v1.Library\"\x1f\n\x11GetLibraryRequest\x12\n\n\x02id\x18\x01 \x01(\t\"8\n\x12GetLibraryResponse\x12\"\n\x07library\x18\x01 \x01(\x0b\x32\x11.exome.v1.Library\"@\n\x17GetLibraryByNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\">\n\x18GetLibraryByNameResponse\x12\"\n\x07library\x18\x01 \x01(\x0b\x32\x11.exome.v1.Library\"_\n\x07\x43\x61talog\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nlibrary_id\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\t\x12\x12\n\nupdated_at\x18\x05 \x01(\t\"8\n\x14\x43reateCatalogRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nlibrary_id\x18\x02 \x01(\t\"#\n\x15\x43reateCatalogResponse\x12\n\n\x02id\x18\x01 \x01(\t\"\x1f\n\x11GetCatalogRequest\x12\n\n\x02id\x18\x01 \x01(\t\"8\n\x12GetCatalogResponse\x12\"\n\x07\x63\x61talog\x18\x01 \x01(\x0b\x32\x11.exome.v1.Catalog\")\n\x13ListCatalogsRequest\x12\x12\n\nlibrary_id\x18\x01 \x01(\t\";\n\x14ListCatalogsResponse\x12#\n\x08\x63\x61talogs\x18\x01 \x03(\x0b\x32\x11.exome.v1.Catalog\";\n\x17GetCatalogByNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nlibrary_id\x18\x02 \x01(\t\">\n\x18GetCatalogByNameResponse\x12\"\n\x07\x63\x61talog\x18\x01 \x01(\x0b\x32\x11.exome.v1.Catalog\"\xa8\x01\n\x06Schema\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tauthority\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x12\n\nis_listing\x18\x06 \x01(\x08\x12\x12\n\ncreated_at\x18\x07 \x01(\t\x12\x12\n\nupdated_at\x18\x08 \x01(\t\x12\x12\n\ncatalog_id\x18\t \x01(\t\"\x81\x01\n\x13\x43reateSchemaRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tauthority\x18\x03 \x01(\t\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x12\n\nis_listing\x18\x05 \x01(\x08\x12\x12\n\ncatalog_id\x18\x06 \x01(\t\"\"\n\x14\x43reateSchemaResponse\x12\n\n\x02id\x18\x01 \x01(\t\"(\n\x12ListSchemasRequest\x12\x12\n\ncatalog_id\x18\x01 \x01(\t\"8\n\x13ListSchemasResponse\x12!\n\x07schemas\x18\x01 \x03(\x0b\x32\x10.exome.v1.Schema\"\x1e\n\x10GetSchemaRequest\x12\n\n\x02id\x18\x01 \x01(\t\"5\n\x11GetSchemaResponse\x12 \n\x06schema\x18\x01 \x01(\x0b\x32\x10.exome.v1.Schema\":\n\x16GetSchemaByNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\";\n\x17GetSchemaByNameResponse\x12 \n\x06schema\x18\x01 \x01(\x0b\x32\x10.exome.v1.Schema\"\xc9\x01\n\x05Table\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x11\n\tschema_id\x18\x05 \x01(\t\x12\x13\n\x0b\x66ile_format\x18\x06 \x01(\t\x12\x12\n\nis_listing\x18\x07 \x01(\x08\x12\x12\n\ncreated_at\x18\x08 \x01(\t\x12\x12\n\nupdated_at\x18\t \x01(\t\x12\x1b\n\x13\x63ompression_type_id\x18\n \x01(\t\"\x85\x01\n\x12\x43reateTableRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x11\n\tschema_id\x18\x04 \x01(\t\x12\x13\n\x0b\x66ile_format\x18\x05 \x01(\t\x12\x12\n\nis_listing\x18\x06 \x01(\x08\"!\n\x13\x43reateTableResponse\x12\n\n\x02id\x18\x01 \x01(\t\"\x1d\n\x0fGetTableRequest\x12\n\n\x02id\x18\x01 \x01(\t\"2\n\x10GetTableResponse\x12\x1e\n\x05table\x18\x01 \x01(\x0b\x32\x0f.exome.v1.Table\"&\n\x11ListTablesRequest\x12\x11\n\tschema_id\x18\x01 \x01(\t\"5\n\x12ListTablesResponse\x12\x1f\n\x06tables\x18\x01 \x03(\x0b\x32\x0f.exome.v1.Table\"8\n\x15GetTableByNameRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tschema_id\x18\x02 \x01(\t\"8\n\x16GetTableByNameResponse\x12\x1e\n\x05table\x18\x01 \x01(\x0b\x32\x0f.exome.v1.Table\"\xbe\x01\n\x0cUserAuditLog\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x17\n\x0forganization_id\x18\x03 \x01(\t\x12\x0c\n\x04role\x18\x04 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x05 \x01(\t\x12\x1a\n\x12target_entity_type\x18\x06 \x01(\t\x12\x18\n\x10target_entity_id\x18\x07 \x01(\t\x12\x12\n\ncreated_at\x18\x08 \x01(\t\x12\x12\n\nupdated_at\x18\t \x01(\t\"1\n\x16GetUserAuditLogRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\"?\n\x17GetUserAuditLogResponse\x12$\n\x04logs\x18\x01 \x03(\x0b\x32\x16.exome.v1.UserAuditLog2\xf7\x10\n\x0e\x43\x61talogService\x12R\n\rCreateLibrary\x12\x1e.exome.v1.CreateLibraryRequest\x1a\x1f.exome.v1.CreateLibraryResponse\"\x00\x12R\n\rListLibraries\x12\x1e.exome.v1.ListLibrariesRequest\x1a\x1f.exome.v1.ListLibrariesResponse\"\x00\x12I\n\nGetLibrary\x12\x1b.exome.v1.GetLibraryRequest\x1a\x1c.exome.v1.GetLibraryResponse\"\x00\x12[\n\x10GetLibraryByName\x12!.exome.v1.GetLibraryByNameRequest\x1a\".exome.v1.GetLibraryByNameResponse\"\x00\x12R\n\rCreateCatalog\x12\x1e.exome.v1.CreateCatalogRequest\x1a\x1f.exome.v1.CreateCatalogResponse\"\x00\x12I\n\nGetCatalog\x12\x1b.exome.v1.GetCatalogRequest\x1a\x1c.exome.v1.GetCatalogResponse\"\x00\x12O\n\x0cListCatalogs\x12\x1d.exome.v1.ListCatalogsRequest\x1a\x1e.exome.v1.ListCatalogsResponse\"\x00\x12[\n\x10GetCatalogByName\x12!.exome.v1.GetCatalogByNameRequest\x1a\".exome.v1.GetCatalogByNameResponse\"\x00\x12O\n\x0c\x43reateSchema\x12\x1d.exome.v1.CreateSchemaRequest\x1a\x1e.exome.v1.CreateSchemaResponse\"\x00\x12L\n\x0bListSchemas\x12\x1c.exome.v1.ListSchemasRequest\x1a\x1d.exome.v1.ListSchemasResponse\"\x00\x12\x46\n\tGetSchema\x12\x1a.exome.v1.GetSchemaRequest\x1a\x1b.exome.v1.GetSchemaResponse\"\x00\x12X\n\x0fGetSchemaByName\x12 .exome.v1.GetSchemaByNameRequest\x1a!.exome.v1.GetSchemaByNameResponse\"\x00\x12L\n\x0b\x43reateTable\x12\x1c.exome.v1.CreateTableRequest\x1a\x1d.exome.v1.CreateTableResponse\"\x00\x12I\n\nListTables\x12\x1b.exome.v1.ListTablesRequest\x1a\x1c.exome.v1.ListTablesResponse\"\x00\x12\x43\n\x08GetTable\x12\x19.exome.v1.GetTableRequest\x1a\x1a.exome.v1.GetTableResponse\"\x00\x12U\n\x0eGetTableByName\x12\x1f.exome.v1.GetTableByNameRequest\x1a .exome.v1.GetTableByNameResponse\"\x00\x12X\n\x0fListFileFormats\x12 .exome.v1.ListFileFormatsRequest\x1a!.exome.v1.ListFileFormatsResponse\"\x00\x12I\n\nCreateUser\x12\x1b.exome.v1.CreateUserRequest\x1a\x1c.exome.v1.CreateUserResponse\"\x00\x12m\n\x16\x43reateUserAuthProvider\x12\'.exome.v1.CreateUserAuthProviderRequest\x1a(.exome.v1.CreateUserAuthProviderResponse\"\x00\x12\x43\n\x08GetToken\x12\x19.exome.v1.GetTokenRequest\x1a\x1a.exome.v1.GetTokenResponse\"\x00\x12@\n\x07GetUser\x12\x18.exome.v1.GetUserRequest\x1a\x19.exome.v1.GetUserResponse\"\x00\x12U\n\x0eGetUserByEmail\x12\x1f.exome.v1.GetUserByEmailRequest\x1a .exome.v1.GetUserByEmailResponse\"\x00\x12g\n\x14GetUserOrganizations\x12%.exome.v1.GetUserOrganizationsRequest\x1a&.exome.v1.GetUserOrganizationsResponse\"\x00\x12X\n\x0fGetOrganization\x12 .exome.v1.GetOrganizationRequest\x1a!.exome.v1.GetOrganizationResponse\"\x00\x12X\n\x0fGetUserAuditLog\x12 .exome.v1.GetUserAuditLogRequest\x1a!.exome.v1.GetUserAuditLogResponse\"\x00\x12\x43\n\x08RunQuery\x12\x19.exome.v1.RunQueryRequest\x1a\x1a.exome.v1.RunQueryResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exome.v1.catalog_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETTOKENREQUEST']._serialized_start=36
  _globals['_GETTOKENREQUEST']._serialized_end=86
  _globals['_GETTOKENRESPONSE']._serialized_start=88
  _globals['_GETTOKENRESPONSE']._serialized_end=121
  _globals['_RUNQUERYREQUEST']._serialized_start=123
  _globals['_RUNQUERYREQUEST']._serialized_end=200
  _globals['_RUNQUERYRESPONSE']._serialized_start=202
  _globals['_RUNQUERYRESPONSE']._serialized_end=241
  _globals['_ORGANIZATION']._serialized_start=243
  _globals['_ORGANIZATION']._serialized_end=323
  _globals['_GETORGANIZATIONREQUEST']._serialized_start=325
  _globals['_GETORGANIZATIONREQUEST']._serialized_end=374
  _globals['_GETORGANIZATIONRESPONSE']._serialized_start=376
  _globals['_GETORGANIZATIONRESPONSE']._serialized_end=447
  _globals['_GETUSERORGANIZATIONSREQUEST']._serialized_start=449
  _globals['_GETUSERORGANIZATIONSREQUEST']._serialized_end=493
  _globals['_GETUSERORGANIZATIONSRESPONSE']._serialized_start=495
  _globals['_GETUSERORGANIZATIONSRESPONSE']._serialized_end=572
  _globals['_USER']._serialized_start=574
  _globals['_USER']._serialized_end=674
  _globals['_CREATEUSERREQUEST']._serialized_start=676
  _globals['_CREATEUSERREQUEST']._serialized_end=749
  _globals['_CREATEUSERRESPONSE']._serialized_start=751
  _globals['_CREATEUSERRESPONSE']._serialized_end=786
  _globals['_CREATEUSERAUTHPROVIDERREQUEST']._serialized_start=788
  _globals['_CREATEUSERAUTHPROVIDERREQUEST']._serialized_end=878
  _globals['_CREATEUSERAUTHPROVIDERRESPONSE']._serialized_start=880
  _globals['_CREATEUSERAUTHPROVIDERRESPONSE']._serialized_end=912
  _globals['_GETUSERREQUEST']._serialized_start=914
  _globals['_GETUSERREQUEST']._serialized_end=945
  _globals['_GETUSERRESPONSE']._serialized_start=947
  _globals['_GETUSERRESPONSE']._serialized_end=994
  _globals['_GETUSERBYEMAILREQUEST']._serialized_start=996
  _globals['_GETUSERBYEMAILREQUEST']._serialized_end=1034
  _globals['_GETUSERBYEMAILRESPONSE']._serialized_start=1036
  _globals['_GETUSERBYEMAILRESPONSE']._serialized_end=1090
  _globals['_LISTFILEFORMATSREQUEST']._serialized_start=1092
  _globals['_LISTFILEFORMATSREQUEST']._serialized_end=1116
  _globals['_LISTFILEFORMATSRESPONSE']._serialized_start=1118
  _globals['_LISTFILEFORMATSRESPONSE']._serialized_end=1187
  _globals['_FILEFORMAT']._serialized_start=1189
  _globals['_FILEFORMAT']._serialized_end=1255
  _globals['_LIBRARY']._serialized_start=1257
  _globals['_LIBRARY']._serialized_end=1353
  _globals['_CREATELIBRARYREQUEST']._serialized_start=1355
  _globals['_CREATELIBRARYREQUEST']._serialized_end=1437
  _globals['_CREATELIBRARYRESPONSE']._serialized_start=1439
  _globals['_CREATELIBRARYRESPONSE']._serialized_end=1474
  _globals['_LISTLIBRARIESREQUEST']._serialized_start=1476
  _globals['_LISTLIBRARIESREQUEST']._serialized_end=1523
  _globals['_LISTLIBRARIESRESPONSE']._serialized_start=1525
  _globals['_LISTLIBRARIESRESPONSE']._serialized_end=1586
  _globals['_GETLIBRARYREQUEST']._serialized_start=1588
  _globals['_GETLIBRARYREQUEST']._serialized_end=1619
  _globals['_GETLIBRARYRESPONSE']._serialized_start=1621
  _globals['_GETLIBRARYRESPONSE']._serialized_end=1677
  _globals['_GETLIBRARYBYNAMEREQUEST']._serialized_start=1679
  _globals['_GETLIBRARYBYNAMEREQUEST']._serialized_end=1743
  _globals['_GETLIBRARYBYNAMERESPONSE']._serialized_start=1745
  _globals['_GETLIBRARYBYNAMERESPONSE']._serialized_end=1807
  _globals['_CATALOG']._serialized_start=1809
  _globals['_CATALOG']._serialized_end=1904
  _globals['_CREATECATALOGREQUEST']._serialized_start=1906
  _globals['_CREATECATALOGREQUEST']._serialized_end=1962
  _globals['_CREATECATALOGRESPONSE']._serialized_start=1964
  _globals['_CREATECATALOGRESPONSE']._serialized_end=1999
  _globals['_GETCATALOGREQUEST']._serialized_start=2001
  _globals['_GETCATALOGREQUEST']._serialized_end=2032
  _globals['_GETCATALOGRESPONSE']._serialized_start=2034
  _globals['_GETCATALOGRESPONSE']._serialized_end=2090
  _globals['_LISTCATALOGSREQUEST']._serialized_start=2092
  _globals['_LISTCATALOGSREQUEST']._serialized_end=2133
  _globals['_LISTCATALOGSRESPONSE']._serialized_start=2135
  _globals['_LISTCATALOGSRESPONSE']._serialized_end=2194
  _globals['_GETCATALOGBYNAMEREQUEST']._serialized_start=2196
  _globals['_GETCATALOGBYNAMEREQUEST']._serialized_end=2255
  _globals['_GETCATALOGBYNAMERESPONSE']._serialized_start=2257
  _globals['_GETCATALOGBYNAMERESPONSE']._serialized_end=2319
  _globals['_SCHEMA']._serialized_start=2322
  _globals['_SCHEMA']._serialized_end=2490
  _globals['_CREATESCHEMAREQUEST']._serialized_start=2493
  _globals['_CREATESCHEMAREQUEST']._serialized_end=2622
  _globals['_CREATESCHEMARESPONSE']._serialized_start=2624
  _globals['_CREATESCHEMARESPONSE']._serialized_end=2658
  _globals['_LISTSCHEMASREQUEST']._serialized_start=2660
  _globals['_LISTSCHEMASREQUEST']._serialized_end=2700
  _globals['_LISTSCHEMASRESPONSE']._serialized_start=2702
  _globals['_LISTSCHEMASRESPONSE']._serialized_end=2758
  _globals['_GETSCHEMAREQUEST']._serialized_start=2760
  _globals['_GETSCHEMAREQUEST']._serialized_end=2790
  _globals['_GETSCHEMARESPONSE']._serialized_start=2792
  _globals['_GETSCHEMARESPONSE']._serialized_end=2845
  _globals['_GETSCHEMABYNAMEREQUEST']._serialized_start=2847
  _globals['_GETSCHEMABYNAMEREQUEST']._serialized_end=2905
  _globals['_GETSCHEMABYNAMERESPONSE']._serialized_start=2907
  _globals['_GETSCHEMABYNAMERESPONSE']._serialized_end=2966
  _globals['_TABLE']._serialized_start=2969
  _globals['_TABLE']._serialized_end=3170
  _globals['_CREATETABLEREQUEST']._serialized_start=3173
  _globals['_CREATETABLEREQUEST']._serialized_end=3306
  _globals['_CREATETABLERESPONSE']._serialized_start=3308
  _globals['_CREATETABLERESPONSE']._serialized_end=3341
  _globals['_GETTABLEREQUEST']._serialized_start=3343
  _globals['_GETTABLEREQUEST']._serialized_end=3372
  _globals['_GETTABLERESPONSE']._serialized_start=3374
  _globals['_GETTABLERESPONSE']._serialized_end=3424
  _globals['_LISTTABLESREQUEST']._serialized_start=3426
  _globals['_LISTTABLESREQUEST']._serialized_end=3464
  _globals['_LISTTABLESRESPONSE']._serialized_start=3466
  _globals['_LISTTABLESRESPONSE']._serialized_end=3519
  _globals['_GETTABLEBYNAMEREQUEST']._serialized_start=3521
  _globals['_GETTABLEBYNAMEREQUEST']._serialized_end=3577
  _globals['_GETTABLEBYNAMERESPONSE']._serialized_start=3579
  _globals['_GETTABLEBYNAMERESPONSE']._serialized_end=3635
  _globals['_USERAUDITLOG']._serialized_start=3638
  _globals['_USERAUDITLOG']._serialized_end=3828
  _globals['_GETUSERAUDITLOGREQUEST']._serialized_start=3830
  _globals['_GETUSERAUDITLOGREQUEST']._serialized_end=3879
  _globals['_GETUSERAUDITLOGRESPONSE']._serialized_start=3881
  _globals['_GETUSERAUDITLOGRESPONSE']._serialized_end=3944
  _globals['_CATALOGSERVICE']._serialized_start=3947
  _globals['_CATALOGSERVICE']._serialized_end=6114
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exome/v1/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65xome/v1/health_check.proto\x12\x08\x65xome.v1\"%\n\x12HealthCheckRequest\x12\x0f\n\x07service\x18\x01 \x01(\t\"\xa3\x01\n\x13HealthCheckResponse\x12;\n\x06status\x18\x01 \x01(\x0e\x32+.exome.v1.HealthCheckResponse.ServingStatus\"O\n\rServingStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVING\x10\x01\x12\x0f\n\x0bNOT_SERVING\x10\x02\x12\x13\n\x0fSERVICE_UNKNOWN\x10\x03\x32P\n\x06Health\x12\x46\n\x05\x43heck\x12\x1c.exome.v1.HealthCheckRequest\x1a\x1d.exome.v1.HealthCheckResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exome.v1.health_check_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_HEALTHCHECKREQUEST']._serialized_start=41
  _globals['_HEALTHCHECKREQUEST']._serialized_end=78
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=81
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=244
  _globals['_HEALTHCHECKRESPONSE_SERVINGSTATUS']._serialized_start=165
  _globals['_HEALTHCHECKRESPONSE_SERVINGSTATUS']._serialized_end=244
  _globals['_HEALTH']._serialized_start=246
  _globals['_HEALTH']._serialized_end=326
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetTokenRequest(_message.Message):
    __slots__ = ["email", "password"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    email: str
    password: str
    def __init__(self, email: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class GetTokenResponse(_message.Message):
    __slots__ = ["token"]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...

class RunQueryRequest(_message.Message):
    __slots__ = ["query", "library_id", "organization_id"]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    LIBRARY_ID_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    query: str
    library_id: str
    organization_id: str
    def __init__(self, query: _Optional[str] = ..., library_id: _Optional[str] = ..., organization_id: _Optional[str] = ...) -> None: ...

class RunQueryResponse(_message.Message):
    __slots__ = ["ipcResponse"]
    IPCRESPONSE_FIELD_NUMBER: _ClassVar[int]
    ipcResponse: bytes
    def __init__(self, ipcResponse: _Optional[bytes] = ...) -> None: ...

class Organization(_message.Message):
    __slots__ = ["id", "name", "created_at", "updated_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    created_at: str
    updated_at: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ...) -> None: ...

class GetOrganizationRequest(_message.Message):
    __slots__ = ["organization_id"]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    def __init__(self, organization_id: _Optional[str] = ...) -> None: ...

class GetOrganizationResponse(_message.Message):
    __slots__ = ["organization"]
    ORGANIZATION_FIELD_NUMBER: _ClassVar[int]
    organization: Organization
    def __init__(self, organization: _Optional[_Union[Organization, _Mapping]] = ...) -> None: ...

class GetUserOrganizationsRequest(_message.Message):
    __slots__ = ["email"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    email: str
    def __init__(self, email: _Optional[str] = ...) -> None: ...

class GetUserOrganizationsResponse(_message.Message):
    __slots__ = ["organizations"]
    ORGANIZATIONS_FIELD_NUMBER: _ClassVar[int]
    organizations: _containers.RepeatedCompositeFieldContainer[Organization]
    def __init__(self, organizations: _Optional[_Iterable[_Union[Organization, _Mapping]]] = ...) -> None: ...

class User(_message.Message):
    __slots__ = ["email", "first_name", "last_name", "created_at", "updated_at"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    email: str
    first_name: str
    last_name: str
    created_at: str
    updated_at: str
    def __init__(self, email: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ...) -> None: ...

class CreateUserRequest(_message.Message):
    __slots__ = ["email", "first_name", "last_name"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    email: str
    first_name: str
    last_name: str
    def __init__(self, email: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ...) -> None: ...

class CreateUserResponse(_message.Message):
    __slots__ = ["email"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    email: str
    def __init__(self, email: _Optional[str] = ...) -> None: ...

class CreateUserAuthProviderRequest(_message.Message):
    __slots__ = ["auth_service", "auth_id", "user_email"]
    AUTH_SERVICE_FIELD_NUMBER: _ClassVar[int]
    AUTH_ID_FIELD_NUMBER: _ClassVar[int]
    USER_EMAIL_FIELD_NUMBER: _ClassVar[int]
    auth_service: str
    auth_id: str
    user_email: str
    def __init__(self, auth_service: _Optional[str] = ..., auth_id: _Optional[str] = ..., user_email: _Optional[str] = ...) -> None: ...

class CreateUserAuthProviderResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetUserRequest(_message.Message):
    __slots__ = ["email"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    email: str
    def __init__(self, email: _Optional[str] = ...) -> None: ...

class GetUserResponse(_message.Message):
    __slots__ = ["user"]
    USER_FIELD_NUMBER: _ClassVar[int]
    user: User
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ...) -> None: ...

class GetUserByEmailRequest(_message.Message):
    __slots__ = ["email"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    email: str
    def __init__(self, email: _Optional[str] = ...) -> None: ...

class GetUserByEmailResponse(_message.Message):
    __slots__ = ["user"]
    USER_FIELD_NUMBER: _ClassVar[int]
    user: User
    def __init__(self, user: _Optional[_Union[User, _Mapping]] = ...) -> None: ...

class ListFileFormatsRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListFileFormatsResponse(_message.Message):
    __slots__ = ["file_formats"]
    FILE_FORMATS_FIELD_NUMBER: _ClassVar[int]
    file_formats: _containers.RepeatedCompositeFieldContainer[FileFormat]
    def __init__(self, file_formats: _Optional[_Iterable[_Union[FileFormat, _Mapping]]] = ...) -> None: ...

class FileFormat(_message.Message):
    __slots__ = ["name", "created_at", "updated_at"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    name: str
    created_at: str
    updated_at: str
    def __init__(self, name: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ...) -> None: ...

class Library(_message.Message):
    __slots__ = ["id", "name", "description", "created_at", "updated_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    created_at: str
    updated_at: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ...) -> None: ...

class CreateLibraryRequest(_message.Message):
    __slots__ = ["name", "description", "organization_id"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    organization_id: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., organization_id: _Optional[str] = ...) -> None: ...

class CreateLibraryResponse(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ListLibrariesRequest(_message.Message):
    __slots__ = ["organization_id"]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    def __init__(self, organization_id: _Optional[str] = ...) -> None: ...

class ListLibrariesResponse(_message.Message):
    __slots__ = ["libraries"]
    LIBRARIES_FIELD_NUMBER: _ClassVar[int]
    libraries: _containers.RepeatedCompositeFieldContainer[Library]
    def __init__(self, libraries: _Optional[_Iterable[_Union[Library, _Mapping]]] = ...) -> None: ...

class GetLibraryRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetLibraryResponse(_message.Message):
    __slots__ = ["library"]
    LIBRARY_FIELD_NUMBER: _ClassVar[int]
    library: Library
    def __init__(self, library: _Optional[_Union[Library, _Mapping]] = ...) -> None: ...

class GetLibraryByNameRequest(_message.Message):
    __slots__ = ["name", "organization_id"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    organization_id: str
    def __init__(self, name: _Optional[str] = ..., organization_id: _Optional[str] = ...) -> None: ...

class GetLibraryByNameResponse(_message.Message):
    __slots__ = ["library"]
    LIBRARY_FIELD_NUMBER: _ClassVar[int]
    library: Library
    def __init__(self, library: _Optional[_Union[Library, _Mapping]] = ...) -> None: ...

class Catalog(_message.Message):
    __slots__ = ["id", "name", "library_id", "created_at", "updated_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    LIBRARY_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    library_id: str
    created_at: str
    updated_at: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., library_id: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ...) -> None: ...

class CreateCatalogRequest(_message.Message):
    __slots__ = ["name", "library_id"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    LIBRARY_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    library_id: str
    def __init__(self, name: _Optional[str] = ..., library_id: _Optional[str] = ...) -> None: ...

class CreateCatalogResponse(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetCatalogRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetCatalogResponse(_message.Message):
    __slots__ = ["catalog"]
    CATALOG_FIELD_NUMBER: _ClassVar[int]
    catalog: Catalog
    def __init__(self, catalog: _Optional[_Union[Catalog, _Mapping]] = ...) -> None: ...

class ListCatalogsRequest(_message.Message):
    __slots__ = ["library_id"]
    LIBRARY_ID_FIELD_NUMBER: _ClassVar[int]
    library_id: str
    def __init__(self, library_id: _Optional[str] = ...) -> None: ...

class ListCatalogsResponse(_message.Message):
    __slots__ = ["catalogs"]
    CATALOGS_FIELD_NUMBER: _ClassVar[int]
    catalogs: _containers.RepeatedCompositeFieldContainer[Catalog]
    def __init__(self, catalogs: _Optional[_Iterable[_Union[Catalog, _Mapping]]] = ...) -> None: ...

class GetCatalogByNameRequest(_message.Message):
    __slots__ = ["name", "library_id"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    LIBRARY_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    library_id: str
    def __init__(self, name: _Optional[str] = ..., library_id: _Optional[str] = ...) -> None: ...

class GetCatalogByNameResponse(_message.Message):
    __slots__ = ["catalog"]
    CATALOG_FIELD_NUMBER: _ClassVar[int]
    catalog: Catalog
    def __init__(self, catalog: _Optional[_Union[Catalog, _Mapping]] = ...) -> None: ...

class Schema(_message.Message):
    __slots__ = ["id", "name", "description", "authority", "path", "is_listing", "created_at", "updated_at", "catalog_id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    IS_LISTING_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    CATALOG_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    authority: str
    path: str
    is_listing: bool
    created_at: str
    updated_at: str
    catalog_id: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., authority: _Optional[str] = ..., path: _Optional[str] = ..., is_listing: bool = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ..., catalog_id: _Optional[str] = ...) -> None: ...

class CreateSchemaRequest(_message.Message):
    __slots__ = ["name", "description", "authority", "path", "is_listing", "catalog_id"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    IS_LISTING_FIELD_NUMBER: _ClassVar[int]
    CATALOG_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    authority: str
    path: str
    is_listing: bool
    catalog_id: str
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., authority: _Optional[str] = ..., path: _Optional[str] = ..., is_listing: bool = ..., catalog_id: _Optional[str] = ...) -> None: ...

class CreateSchemaResponse(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class ListSchemasRequest(_message.Message):
    __slots__ = ["catalog_id"]
    CATALOG_ID_FIELD_NUMBER: _ClassVar[int]
    catalog_id: str
    def __init__(self, catalog_id: _Optional[str] = ...) -> None: ...

class ListSchemasResponse(_message.Message):
    __slots__ = ["schemas"]
    SCHEMAS_FIELD_NUMBER: _ClassVar[int]
    schemas: _containers.RepeatedCompositeFieldContainer[Schema]
    def __init__(self, schemas: _Optional[_Iterable[_Union[Schema, _Mapping]]] = ...) -> None: ...

class GetSchemaRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetSchemaResponse(_message.Message):
    __slots__ = ["schema"]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    schema: Schema
    def __init__(self, schema: _Optional[_Union[Schema, _Mapping]] = ...) -> None: ...

class GetSchemaByNameRequest(_message.Message):
    __slots__ = ["name", "catalog_id"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CATALOG_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    catalog_id: str
    def __init__(self, name: _Optional[str] = ..., catalog_id: _Optional[str] = ...) -> None: ...

class GetSchemaByNameResponse(_message.Message):
    __slots__ = ["schema"]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    schema: Schema
    def __init__(self, schema: _Optional[_Union[Schema, _Mapping]] = ...) -> None: ...

class Table(_message.Message):
    __slots__ = ["id", "name", "description", "location", "schema_id", "file_format", "is_listing", "created_at", "updated_at", "compression_type_id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_ID_FIELD_NUMBER: _ClassVar[int]
    FILE_FORMAT_FIELD_NUMBER: _ClassVar[int]
    IS_LISTING_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    COMPRESSION_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    location: str
    schema_id: str
    file_format: str
    is_listing: bool
    created_at: str
    updated_at: str
    compression_type_id: str
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., location: _Optional[str] = ..., schema_id: _Optional[str] = ..., file_format: _Optional[str] = ..., is_listing: bool = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ..., compression_type_id: _Optional[str] = ...) -> None: ...

class CreateTableRequest(_message.Message):
    __slots__ = ["name", "description", "location", "schema_id", "file_format", "is_listing"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LOCATION_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_ID_FIELD_NUMBER: _ClassVar[int]
    FILE_FORMAT_FIELD_NUMBER: _ClassVar[int]
    IS_LISTING_FIELD_NUMBER: _ClassVar[int]
    name: str
    description: str
    location: str
    schema_id: str
    file_format: str
    is_listing: bool
    def __init__(self, name: _Optional[str] = ..., description: _Optional[str] = ..., location: _Optional[str] = ..., schema_id: _Optional[str] = ..., file_format: _Optional[str] = ..., is_listing: bool = ...) -> None: ...

class CreateTableResponse(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetTableRequest(_message.Message):
    __slots__ = ["id"]
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetTableResponse(_message.Message):
    __slots__ = ["table"]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    table: Table
    def __init__(self, table: _Optional[_Union[Table, _Mapping]] = ...) -> None: ...

class ListTablesRequest(_message.Message):
    __slots__ = ["schema_id"]
    SCHEMA_ID_FIELD_NUMBER: _ClassVar[int]
    schema_id: str
    def __init__(self, schema_id: _Optional[str] = ...) -> None: ...

class ListTablesResponse(_message.Message):
    __slots__ = ["tables"]
    TABLES_FIELD_NUMBER: _ClassVar[int]
    tables: _containers.RepeatedCompositeFieldContainer[Table]
    def __init__(self, tables: _Optional[_Iterable[_Union[Table, _Mapping]]] = ...) -> None: ...

class GetTableByNameRequest(_message.Message):
    __slots__ = ["name", "schema_id"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_ID_FIELD_NUMBER: _ClassVar[int]
    name: str
    schema_id: str
    def __init__(self, name: _Optional[str] = ..., schema_id: _Optional[str] = ...) -> None: ...

class GetTableByNameResponse(_message.Message):
    __slots__ = ["table"]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    table: Table
    def __init__(self, table: _Optional[_Union[Table, _Mapping]] = ...) -> None: ...

class UserAuditLog(_message.Message):
    __slots__ = ["id", "email", "organization_id", "role", "action", "target_entity_type", "target_entity_id", "created_at", "updated_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    TARGET_ENTITY_TYPE_FIELD_NUMBER: _ClassVar[int]
    TARGET_ENTITY_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    email: str
    organization_id: str
    role: str
    action: str
    target_entity_type: str
    target_entity_id: str
    created_at: str
    updated_at: str
    def __init__(self, id: _Optional[str] = ..., email: _Optional[str] = ..., organization_id: _Optional[str] = ..., role: _Optional[str] = ..., action: _Optional[str] = ..., target_entity_type: _Optional[str] = ..., target_entity_id: _Optional[str] = ..., created_at: _Optional[str] = ..., updated_at: _Optional[str] = ...) -> None: ...

class GetUserAuditLogRequest(_message.Message):
    __slots__ = ["organization_id"]
    ORGANIZATION_ID_FIELD_NUMBER: _ClassVar[int]
    organization_id: str
    def __init__(self, organization_id: _Optional[str] = ...) -> None: ...

class GetUserAuditLogResponse(_message.Message):
    __slots__ = ["logs"]
    LOGS_FIELD_NUMBER: _ClassVar[int]
    logs: _containers.RepeatedCompositeFieldContainer[UserAuditLog]
    def __init__(self, logs: _Optional[_Iterable[_Union[UserAuditLog, _Mapping]]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from exon_py.proto.exome.v1 import catalog_pb2 as exome_dot_v1_dot_catalog__pb2


class CatalogServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateLibrary = channel.unary_unary(
            "/exome.v1.CatalogService/CreateLibrary",
            request_serializer=exome_dot_v1_dot_catalog__pb2.CreateLibraryRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.CreateLibraryResponse.FromString,
        )
        self.ListLibraries = channel.unary_unary(
            "/exome.v1.CatalogService/ListLibraries",
            request_serializer=exome_dot_v1_dot_catalog__pb2.ListLibrariesRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.ListLibrariesResponse.FromString,
        )
        self.GetLibrary = channel.unary_unary(
            "/exome.v1.CatalogService/GetLibrary",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetLibraryRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetLibraryResponse.FromString,
        )
        self.GetLibraryByName = channel.unary_unary(
            "/exome.v1.CatalogService/GetLibraryByName",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetLibraryByNameRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetLibraryByNameResponse.FromString,
        )
        self.CreateCatalog = channel.unary_unary(
            "/exome.v1.CatalogService/CreateCatalog",
            request_serializer=exome_dot_v1_dot_catalog__pb2.CreateCatalogRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.CreateCatalogResponse.FromString,
        )
        self.GetCatalog = channel.unary_unary(
            "/exome.v1.CatalogService/GetCatalog",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetCatalogRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetCatalogResponse.FromString,
        )
        self.ListCatalogs = channel.unary_unary(
            "/exome.v1.CatalogService/ListCatalogs",
            request_serializer=exome_dot_v1_dot_catalog__pb2.ListCatalogsRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.ListCatalogsResponse.FromString,
        )
        self.GetCatalogByName = channel.unary_unary(
            "/exome.v1.CatalogService/GetCatalogByName",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetCatalogByNameRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetCatalogByNameResponse.FromString,
        )
        self.CreateSchema = channel.unary_unary(
            "/exome.v1.CatalogService/CreateSchema",
            request_serializer=exome_dot_v1_dot_catalog__pb2.CreateSchemaRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.CreateSchemaResponse.FromString,
        )
        self.ListSchemas = channel.unary_unary(
            "/exome.v1.CatalogService/ListSchemas",
            request_serializer=exome_dot_v1_dot_catalog__pb2.ListSchemasRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.ListSchemasResponse.FromString,
        )
        self.GetSchema = channel.unary_unary(
            "/exome.v1.CatalogService/GetSchema",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetSchemaRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetSchemaResponse.FromString,
        )
        self.GetSchemaByName = channel.unary_unary(
            "/exome.v1.CatalogService/GetSchemaByName",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetSchemaByNameRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetSchemaByNameResponse.FromString,
        )
        self.CreateTable = channel.unary_unary(
            "/exome.v1.CatalogService/CreateTable",
            request_serializer=exome_dot_v1_dot_catalog__pb2.CreateTableRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.CreateTableResponse.FromString,
        )
        self.ListTables = channel.unary_unary(
            "/exome.v1.CatalogService/ListTables",
            request_serializer=exome_dot_v1_dot_catalog__pb2.ListTablesRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.ListTablesResponse.FromString,
        )
        self.GetTable = channel.unary_unary(
            "/exome.v1.CatalogService/GetTable",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetTableRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetTableResponse.FromString,
        )
        self.GetTableByName = channel.unary_unary(
            "/exome.v1.CatalogService/GetTableByName",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetTableByNameRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetTableByNameResponse.FromString,
        )
        self.ListFileFormats = channel.unary_unary(
            "/exome.v1.CatalogService/ListFileFormats",
            request_serializer=exome_dot_v1_dot_catalog__pb2.ListFileFormatsRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.ListFileFormatsResponse.FromString,
        )
        self.CreateUser = channel.unary_unary(
            "/exome.v1.CatalogService/CreateUser",
            request_serializer=exome_dot_v1_dot_catalog__pb2.CreateUserRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.CreateUserResponse.FromString,
        )
        self.CreateUserAuthProvider = channel.unary_unary(
            "/exome.v1.CatalogService/CreateUserAuthProvider",
            request_serializer=exome_dot_v1_dot_catalog__pb2.CreateUserAuthProviderRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.CreateUserAuthProviderResponse.FromString,
        )
        self.GetToken = channel.unary_unary(
            "/exome.v1.CatalogService/GetToken",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetTokenRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetTokenResponse.FromString,
        )
        self.GetUser = channel.unary_unary(
            "/exome.v1.CatalogService/GetUser",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetUserRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetUserResponse.FromString,
        )
        self.GetUserByEmail = channel.unary_unary(
            "/exome.v1.CatalogService/GetUserByEmail",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetUserByEmailRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetUserByEmailResponse.FromString,
        )
        self.GetUserOrganizations = channel.unary_unary(
            "/exome.v1.CatalogService/GetUserOrganizations",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetUserOrganizationsRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetUserOrganizationsResponse.FromString,
        )
        self.GetOrganization = channel.unary_unary(
            "/exome.v1.CatalogService/GetOrganization",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetOrganizationRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetOrganizationResponse.FromString,
        )
        self.GetUserAuditLog = channel.unary_unary(
            "/exome.v1.CatalogService/GetUserAuditLog",
            request_serializer=exome_dot_v1_dot_catalog__pb2.GetUserAuditLogRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.GetUserAuditLogResponse.FromString,
        )
        self.RunQuery = channel.unary_unary(
            "/exome.v1.CatalogService/RunQuery",
            request_serializer=exome_dot_v1_dot_catalog__pb2.RunQueryRequest.SerializeToString,
            response_deserializer=exome_dot_v1_dot_catalog__pb2.RunQueryResponse.FromString,
        )


class CatalogServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateLibrary(self, request, context):
        """Library"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListLibraries(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetLibrary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetLibraryByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateCatalog(self, request, context):
        """Catalog"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetCatalog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListCatalogs(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetCatalogByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateSchema(self, request, context):
        """Schema"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListSchemas(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetSchemaByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateTable(self, request, context):
        """Table"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListTables(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetTable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetTableByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListFileFormats(self, request, context):
        """File Formats"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateUser(self, request, context):
        """User information."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateUserAuthProvider(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetUserByEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetUserOrganizations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetOrganization(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetUserAuditLog(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def RunQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_CatalogServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CreateLibrary": grpc.unary_unary_rpc_method_handler(
            servicer.CreateLibrary,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.CreateLibraryRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.CreateLibraryResponse.SerializeToString,
        ),
        "ListLibraries": grpc.unary_unary_rpc_method_handler(
            servicer.ListLibraries,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.ListLibrariesRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.ListLibrariesResponse.SerializeToString,
        ),
        "GetLibrary": grpc.unary_unary_rpc_method_handler(
            servicer.GetLibrary,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetLibraryRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetLibraryResponse.SerializeToString,
        ),
        "GetLibraryByName": grpc.unary_unary_rpc_method_handler(
            servicer.GetLibraryByName,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetLibraryByNameRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetLibraryByNameResponse.SerializeToString,
        ),
        "CreateCatalog": grpc.unary_unary_rpc_method_handler(
            servicer.CreateCatalog,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.CreateCatalogRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.CreateCatalogResponse.SerializeToString,
        ),
        "GetCatalog": grpc.unary_unary_rpc_method_handler(
            servicer.GetCatalog,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetCatalogRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetCatalogResponse.SerializeToString,
        ),
        "ListCatalogs": grpc.unary_unary_rpc_method_handler(
            servicer.ListCatalogs,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.ListCatalogsRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.ListCatalogsResponse.SerializeToString,
        ),
        "GetCatalogByName": grpc.unary_unary_rpc_method_handler(
            servicer.GetCatalogByName,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetCatalogByNameRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetCatalogByNameResponse.SerializeToString,
        ),
        "CreateSchema": grpc.unary_unary_rpc_method_handler(
            servicer.CreateSchema,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.CreateSchemaRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.CreateSchemaResponse.SerializeToString,
        ),
        "ListSchemas": grpc.unary_unary_rpc_method_handler(
            servicer.ListSchemas,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.ListSchemasRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.ListSchemasResponse.SerializeToString,
        ),
        "GetSchema": grpc.unary_unary_rpc_method_handler(
            servicer.GetSchema,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetSchemaRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetSchemaResponse.SerializeToString,
        ),
        "GetSchemaByName": grpc.unary_unary_rpc_method_handler(
            servicer.GetSchemaByName,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetSchemaByNameRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetSchemaByNameResponse.SerializeToString,
        ),
        "CreateTable": grpc.unary_unary_rpc_method_handler(
            servicer.CreateTable,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.CreateTableRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.CreateTableResponse.SerializeToString,
        ),
        "ListTables": grpc.unary_unary_rpc_method_handler(
            servicer.ListTables,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.ListTablesRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.ListTablesResponse.SerializeToString,
        ),
        "GetTable": grpc.unary_unary_rpc_method_handler(
            servicer.GetTable,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetTableRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetTableResponse.SerializeToString,
        ),
        "GetTableByName": grpc.unary_unary_rpc_method_handler(
            servicer.GetTableByName,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetTableByNameRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetTableByNameResponse.SerializeToString,
        ),
        "ListFileFormats": grpc.unary_unary_rpc_method_handler(
            servicer.ListFileFormats,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.ListFileFormatsRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.ListFileFormatsResponse.SerializeToString,
        ),
        "CreateUser": grpc.unary_unary_rpc_method_handler(
            servicer.CreateUser,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.CreateUserRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.CreateUserResponse.SerializeToString,
        ),
        "CreateUserAuthProvider": grpc.unary_unary_rpc_method_handler(
            servicer.CreateUserAuthProvider,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.CreateUserAuthProviderRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.CreateUserAuthProviderResponse.SerializeToString,
        ),
        "GetToken": grpc.unary_unary_rpc_method_handler(
            servicer.GetToken,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetTokenRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetTokenResponse.SerializeToString,
        ),
        "GetUser": grpc.unary_unary_rpc_method_handler(
            servicer.GetUser,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetUserRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetUserResponse.SerializeToString,
        ),
        "GetUserByEmail": grpc.unary_unary_rpc_method_handler(
            servicer.GetUserByEmail,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetUserByEmailRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetUserByEmailResponse.SerializeToString,
        ),
        "GetUserOrganizations": grpc.unary_unary_rpc_method_handler(
            servicer.GetUserOrganizations,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetUserOrganizationsRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetUserOrganizationsResponse.SerializeToString,
        ),
        "GetOrganization": grpc.unary_unary_rpc_method_handler(
            servicer.GetOrganization,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetOrganizationRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetOrganizationResponse.SerializeToString,
        ),
        "GetUserAuditLog": grpc.unary_unary_rpc_method_handler(
            servicer.GetUserAuditLog,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.GetUserAuditLogRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.GetUserAuditLogResponse.SerializeToString,
        ),
        "RunQuery": grpc.unary_unary_rpc_method_handler(
            servicer.RunQuery,
            request_deserializer=exome_dot_v1_dot_catalog__pb2.RunQueryRequest.FromString,
            response_serializer=exome_dot_v1_dot_catalog__pb2.RunQueryResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler("exome.v1.CatalogService", rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class CatalogService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateLibrary(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/CreateLibrary",
            exome_dot_v1_dot_catalog__pb2.CreateLibraryRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.CreateLibraryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ListLibraries(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/ListLibraries",
            exome_dot_v1_dot_catalog__pb2.ListLibrariesRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.ListLibrariesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetLibrary(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetLibrary",
            exome_dot_v1_dot_catalog__pb2.GetLibraryRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetLibraryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetLibraryByName(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetLibraryByName",
            exome_dot_v1_dot_catalog__pb2.GetLibraryByNameRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetLibraryByNameResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CreateCatalog(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/CreateCatalog",
            exome_dot_v1_dot_catalog__pb2.CreateCatalogRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.CreateCatalogResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetCatalog(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetCatalog",
            exome_dot_v1_dot_catalog__pb2.GetCatalogRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetCatalogResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ListCatalogs(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/ListCatalogs",
            exome_dot_v1_dot_catalog__pb2.ListCatalogsRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.ListCatalogsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetCatalogByName(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetCatalogByName",
            exome_dot_v1_dot_catalog__pb2.GetCatalogByNameRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetCatalogByNameResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CreateSchema(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/CreateSchema",
            exome_dot_v1_dot_catalog__pb2.CreateSchemaRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.CreateSchemaResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ListSchemas(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/ListSchemas",
            exome_dot_v1_dot_catalog__pb2.ListSchemasRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.ListSchemasResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetSchema(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetSchema",
            exome_dot_v1_dot_catalog__pb2.GetSchemaRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetSchemaResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetSchemaByName(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetSchemaByName",
            exome_dot_v1_dot_catalog__pb2.GetSchemaByNameRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetSchemaByNameResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CreateTable(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/CreateTable",
            exome_dot_v1_dot_catalog__pb2.CreateTableRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.CreateTableResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ListTables(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/ListTables",
            exome_dot_v1_dot_catalog__pb2.ListTablesRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.ListTablesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetTable(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetTable",
            exome_dot_v1_dot_catalog__pb2.GetTableRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetTableResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetTableByName(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetTableByName",
            exome_dot_v1_dot_catalog__pb2.GetTableByNameRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetTableByNameResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ListFileFormats(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/ListFileFormats",
            exome_dot_v1_dot_catalog__pb2.ListFileFormatsRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.ListFileFormatsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CreateUser(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/CreateUser",
            exome_dot_v1_dot_catalog__pb2.CreateUserRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.CreateUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CreateUserAuthProvider(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/CreateUserAuthProvider",
            exome_dot_v1_dot_catalog__pb2.CreateUserAuthProviderRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.CreateUserAuthProviderResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetToken(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetToken",
            exome_dot_v1_dot_catalog__pb2.GetTokenRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetUser(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetUser",
            exome_dot_v1_dot_catalog__pb2.GetUserRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetUserByEmail(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetUserByEmail",
            exome_dot_v1_dot_catalog__pb2.GetUserByEmailRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetUserByEmailResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetUserOrganizations(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetUserOrganizations",
            exome_dot_v1_dot_catalog__pb2.GetUserOrganizationsRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetUserOrganizationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetOrganization(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetOrganization",
            exome_dot_v1_dot_catalog__pb2.GetOrganizationRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetOrganizationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetUserAuditLog(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/GetUserAuditLog",
            exome_dot_v1_dot_catalog__pb2.GetUserAuditLogRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.GetUserAuditLogResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def RunQuery(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/exome.v1.CatalogService/RunQuery",
            exome_dot_v1_dot_catalog__pb2.RunQueryRequest.SerializeToString,
            exome_dot_v1_dot_catalog__pb2.RunQueryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
